@@ -41,16 +41,17 @@ fn get_config_file_path(config_filename: &str) -> String {
 fn get_videos_section_html(file: &str) -> String {
     let mut html_content: String = "".to_owned();
     let video_serializer = video_serializer::Videos::new(file);
-    let categories = settings_serializer::call("config/categories.txt");
     for year in video_serializer.ordered_years() {
         let mut year_fillings = Vec::new();
         let mut yearly_videos: String = "".to_owned();
         for video in video_serializer.select_by_year(year).videos {
             let mut fillings = Vec::new();
-            let category = find_category_name(&categories, video.category_id);
+            let tags = get_tag_section_html(video.tag_id);
+            let description_html = get_description_section_html(video.description.as_str());
             fillings.push(("{{title}}", video.title.as_str()));
             fillings.push(("{{video_id}}", video.video_id.as_str()));
-            fillings.push(("{{category}}", category.as_str()));
+            fillings.push(("{{description}}", &description_html));
+            fillings.push(("{{tags}}", tags.as_str()));
             let video_html = template_filler::call(&video.template_path, fillings);
             yearly_videos.push_str(&video_html)
         }
@@ -63,9 +64,32 @@ fn get_videos_section_html(file: &str) -> String {
     return html_content;
 }
 
-fn find_category_name(categories: &Vec<settings_serializer::Settings>, category_id: String) -> String {
-    let matching_category = categories.iter().find( |s| s.key == category_id);
-    match matching_category {
+fn get_description_section_html(description: &str) -> String {
+    if description == "" {
+        "".to_string()
+    } else {
+        let description_filling = vec![("{{description}}", description)];
+       template_filler::call("templates/description.html", description_filling)
+    }
+}
+
+fn get_tag_section_html(tags: String) -> String {
+    let all_tags = settings_serializer::call("config/tags.txt");
+    let mut html_section: String = "".to_owned();
+    let tags_ids: Vec<String> = tags.split("-").map(str::to_string).collect();
+    for tag_id in tags_ids {
+        let mut tag_fillings = Vec::new();
+        let tag = find_tag_name(&all_tags, tag_id);
+        tag_fillings.push(("{{tag}}", tag.as_str()));
+        let single_tag_html = template_filler::call("templates/tag.html", tag_fillings);
+        html_section.push_str(&single_tag_html);
+    }
+    return html_section;
+}
+
+fn find_tag_name(all_tags: &Vec<settings_serializer::Settings>, tag_id: String) -> String {
+    let matching_tag = all_tags.iter().find( |s| s.key == tag_id);
+    match matching_tag {
         Some(c) => return c.value.to_string(),
         None => return "".to_string(),
     }
