@@ -4,8 +4,9 @@ use crate::data_extractor;
 pub struct Video {
     pub title: String,
     pub video_id: String,
-    pub category_id: String,
+    pub tag_id: String,
     pub year: i32,
+    pub description: String,
     pub template_path: String
 }
 
@@ -13,8 +14,10 @@ impl Video {
     fn new(structured_data: data_extractor::Data) -> Video {
         let key = &structured_data.data[0];
         let value = &structured_data.data[1];
-        let category_id = &structured_data.data[2];
+        let tag_id = &structured_data.data[2];
         let year: i32 = structured_data.data[3].parse().unwrap();
+        let description = structured_data.data.get(4);
+        let empty_description = "".to_string();
         let mut video_id = "".to_string();
         let mut template = "".to_string();
         if value.contains("youtube.com") {
@@ -28,8 +31,9 @@ impl Video {
         Video {
             title: key.to_string(),
             video_id: video_id.to_string(),
-            category_id: category_id.to_string(),
+            tag_id: tag_id.to_string(),
             year: year,
+            description: description.unwrap_or(&empty_description).to_string(),
             template_path: template
         }
     }
